千与千寻 (豆瓣)
Description: 千与千寻电影简介和剧情介绍,千与千寻影评、图片、预告片、影讯、论坛、在线购票
Keywords: 千与千寻,千と千尋の神隠し,千与千寻影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.7豆瓣电影Top250

# 千与千寻 千と千尋の神隠し (2001)

更新描述或海报

导演: 宫崎骏
编剧: 宫崎骏
主演: 柊瑠美 / 入野自由 / 夏木真理 / 菅原文太 / 中村彰男 / 玉井夕海 / 神木隆之介 / 内藤刚志 / 泽口靖子 / 我修院达也 / 大泉洋 / 小林郁夫 / 上条恒彦 / 小野武彦
类型: 剧情 / 动画 / 奇幻
官方网站: http://toho.co.jp/sentochihiro/index2.html
制片国家/地区: 日本
语言: 日语
上映日期: 2019-06-21(中国大陆) / 2001-07-20(日本)
片长: 125分钟
又名: 神隐少女(台) / 千与千寻的神隐 / Spirited Away / A Voyage of Chihiro / Sen to Chihiro no kamikakushi
IMDb: tt0245429
豆瓣评分
引用
9.4
2130519人评价
5星
73.3%
4星
23.1%
3星
3.3%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.3
6人评价
好于 99% 动画片
好于 99% 奇幻片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 千与千寻的剧情简介 · · · · · ·

千寻和爸爸妈妈一同驱车前往新家，在郊外的小路上不慎进入了神秘的隧道——他们去到了另外一个诡异世界—一个中世纪的小镇。远处飘来食物的香味，爸爸妈妈大快朵颐，孰料之后变成了猪！这时小镇上渐渐来了许多样子古怪、半透明的人。
千寻仓皇逃出，一个叫小白的人救了他，喂了她阻止身体消 失的药，并且告诉她怎样去找锅炉爷爷以及汤婆婆，而且必须获得一份工作才能不被魔法变成别的东西。
千寻在小白的帮助下幸运地获得了一份在浴池打杂的工作。渐渐她不再被那些怪模怪样的人吓倒，并从小玲那儿知道了小白是凶恶的汤婆婆的弟子。
一次，千寻发现小白被一群白色飞舞的纸人打伤，为了救受伤的小白，她用河神送给她的药丸驱出了小白身体内的封印以及守封印的小妖精，但小白还是没有醒过来。
为了救小白，千寻又踏上了她的冒险之旅。 ©豆瓣

## 千与千寻的演职员 · · · · · · ( 全部 41 )

- 宫崎骏 导演
- 柊瑠美 配 荻野千寻 Chihiro Ogino / Sen
- 入野自由 配 白龙 ハク Haku
- 夏木真理 配 汤婆婆 / 钱婆婆 Yubaba / Zeniba
- 菅原文太 配 锅炉爷爷 釜爺 Kamajî
- 中村彰男 配 无脸男 カオナシ Kaonashi

## 千与千寻的视频和图片 · · · · · · ( 预告片11 | 视频评论1 · 添加 | 图片2400 · 添加 )

## 千与千寻的获奖情况 · · · · · · ( 全部 )

- 第75届奥斯卡金像奖
- 最佳动画长片
- 宫崎骏

- 第52届柏林国际电影节
- 金熊奖 最佳影片
- 宫崎骏

- 第21届香港电影金像奖
- 最佳亚洲电影

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  幽灵公主

  风之谷

  大闹天宫

  魔女宅急便

  龙猫

  红猪

  怪兽电力公司

  神偷奶爸

我要写短评

## 千与千寻的短评 · · · · · · ( 全部 397326 条 )

热门 / 最新 / 好友

### 4575 有用 南国玫瑰 看过 2008-12-22 22:28:54

有那么那么经典吗？还是我老了？

### 13892 有用 zing 看过 2008-03-07 14:00:22

每次看这些神作的时候想到这是动画片这是一群牛人一笔一笔画出来的,就觉得漏看掉一帧都实在是对不起他们啊

### 16722 有用 8T;GA*%o~""Zn 看过 2006-10-12 16:19:42

不努力工作会变成猪

### 1651 有用 小波福娃 看过 2007-09-18 17:22:12

内个白龙好像塔矢亮！其实这是个爱丽丝漫游奇遇记的东方版呢！

### 11153 有用 ░▒▓██ 看过 2009-11-25 16:42:47

曾发生过的事请不可能忘记 只不过是你想不起罢了

> 更多短评 397326条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:23:38

一个没有故事的女孩遇到一群充满故事的人，然后这个女孩就有了个终生的怀念。

### 0 有用 猴子 看过 2014-02-20 21:19:38

在人生的路上，别丢了自己

### 0 有用 LLudeer 看过 2013-10-07 19:15:33

人性的贪念和纯粹的爱。

我要写影评

## 千与千寻的影评 · · · · · · ( 全部 6849 条 )

热门 / 最新 / 好友
lemon 2005-09-26 17:20:32

## 喜欢《千与千寻》那个无脸怪

看完《千与千寻》，我一直没弄清楚那只无脸怪从哪里来。可要命的是，我对它念念不忘。千寻过桥时，一个黑影子，像个黑布袋，长了一张像白纸面具一样的脸，立在桥边。这个鬼魅一样的脸，目光追随着她，透出隐隐微笑。 这个无脸怪，这个鬼，就飘啊飘。千寻到哪儿，它就飘到哪儿。... (展开)
11025 869 1300回应 收起
邝言 2006-06-08 18:02:32

## 你我都曾有过的梦境

这篇影评可能有剧透

（一）千与千寻之童年情境 我的一个朋友每看到在花丛下白给千寻吃他用魔法做的饭团那一段就泣不成声。很多人不明白，但是我并不奇怪，因为我也是一样。 也许没有童年创伤的孩子不会明白那一段的感人之处。我想也许每个孩子都会幻想自己能够有一个白龙朋友，平时他也就和自己... (展开)
7784 355 647回应 收起
子戈 2018-05-04 09:52:55 #《千与千寻》的主题是什么？为什么如此经典？

## 我更喜欢第二个故事，你呢？

在宫崎骏的《千与千寻》中，我看到了两个截然不同的故事。 第一个故事，关于如何在物欲横流的世界，保持内心的干净。 它让我想起法国诗意现实主义剧作家普莱卫说过的一句话： 生活的信心只有在超越种种磨难之外，在与儿童目光的相接中获得。 说得多好啊。 看到这句话，我才恍然... (展开)
7673 51 300回应 收起
SKY 2006-01-04 00:23:50

## 以自由的名义

这篇影评可能有剧透

迟钝了些，直到昨天，我才看了这部在学校里就早已被大家念叨了千万遍的《千与千寻》，看的是粤语配音版。 在深圳这个相对自由的城市里，我谨以“自由”的名义，写下一点点感想： 有一点从头至尾震憾着我：那就是日本人的教育和思想！为什么日本动画片小孩大人都爱看，我想是因... (展开)
7866 750 591回应 收起
44 2007-08-08 23:25:51

## 转焦文字。

今天又把这个电影看了一遍，感慨良多，说出来，大家听听：） 千与千寻:让我们感动的内涵 孩子不是父母手里拥有的东西，他们要学习这个世界的规则，发掘自己心里的美丽。 千与千寻，就是用童话的形式讲的正在孩子身边发生的现实的故事。 1 父母 父母是普通的城里人，比较重... (展开)
2721 154 217回应 收起
叶子阿姨 2009-04-04 17:50:22

## 千与千寻——成长的童话

1。千寻VS父母：进入另外的世界，成长的开始。 通往新家的路上，父母给千寻说着新环境的优点，而千寻却说，还是以前的学校比较好。好在哪里她没有说，但我想，是因为那里有熟悉的人和快乐的回忆，一旦离开那里，一切都将重新开始。 千寻看见手中的花枯萎了，心里就一阵阵的难过... (展开)
2095 55 133回应 收起
viyu 2005-12-03 03:28:10

## 千与千寻

千与千寻--一直以为这是两个人的名字，结果是一个人的，前一个是被给予的名字，后一个是被剥夺的。这个故事其实是属于两个名字的，琥珀川与千寻。宫崎俊有着天下最迤俪的幻想，他给你的比你想要的还要好。好，伴随着苦难，却不伴随着虚假。好的好，不是残酷的好，不是骇人的好... (展开)
1811 202 194回应 收起
东都 2008-11-19 13:52:18

## 你看懂了千与千寻的神隐吗？？

静静的开端： 我们的时代 生活剧一般的开端。音乐虽然是近似主旋律的那首《あの日の川へ》，但在这里只作为“好听的曲子”而存在着。 风和日丽，道路畅通，乐声轻巧温馨，琐碎的家常谈话--一切都极为流畅，在这里导演无意提及一个“重点”来引起观众的注意。因为那在同时也意... (展开)
1300 43 91回应 收起
小豹子 2009-12-03 15:38:16

## 琥珀川

看到蔡康永说,他看神隐少女最后小白终于得知自己名字然后鳞片剥落的那一刻会落泪.说着说着竟然在康熙来了中哽咽. 有点讶异,于是把这部几年前看过的动画片重新看了一遍. 古赈早琥珀川.白龙的灵片在一霎那闪着光碎去,他们拉着手下坠,他眼镜亮亮地把犹如神明一般的名字告诉她,她... (展开)
1027 52 57回应 收起
容易受伤的男人 2010-05-15 03:37:03

## 《千尋與異境》(修改一次)

電影，首先是關於夢的藝術。而夢，又是擬象的表達。 　　《千與千尋的神隱》並不僅僅是一位少女跟隨父母闖入異鄉的奇異夢幻，還代表了一代日本長輩囑託年輕人的警示之夢。 　　第一次看這部電影的時候我十三歲。當時並不能理解這部電影為什麼能摘取諸多桂冠。 　　在裡... (展开)
818 13 97回应 收起

> 更多影评 6849篇

添加新讨论

## 讨论区 · · · · · ·

重温 | 来自Lly |  | 2022-11-22 22:13:46
小时候看的了 | 来自yain. |  | 2022-11-22 09:38:01
怎么看这个电影 | 来自豆友GYb4TJX_MM |  | 2022-11-22 08:30:10
为什么白龙偷了印章受伤后，汤婆婆要“处理”掉他？ | 来自一个青年 | 1 回应 | 2022-11-21 23:21:28
小千与白龙之间的感情是友情还是爱情？ | 来自路一凡 | 67 回应 | 2022-11-20 21:59:40

> 去这部影片的讨论区（全部1706条）

## 关于《千与千寻》的问题 · · · · · · ( 全部77个 )

- 为什么小白龙说让千寻不要回头呢？ 25人回答
- 为什么千寻家的奥迪车没有后座安全带？ 15人回答

> 全部77个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 80末出生的人是这样成长的 (沉歌)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- 唔昂（考公ing
  刚刚 看过
- 清奈
  1分钟前 看过
- Guofy
  2分钟前 看过

3825589人看过 / 304414人想看

订阅千与千寻的评论:
feed: rss 2.0